# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/greenplum/v1/pxf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'yandex/cloud/mdb/greenplum/v1/pxf.proto\x12\x1dyandex.cloud.mdb.greenplum.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xc5\x04\n\tPXFConfig\x12\x42\n\x12\x63onnection_timeout\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x35-600\x12>\n\x0eupload_timeout\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x35-600\x12<\n\x0bmax_threads\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x31-1024\x12\x42\n\x1epool_allow_core_thread_timeout\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0epool_core_size\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x31-1024\x12\x41\n\x13pool_queue_capacity\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12>\n\rpool_max_size\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x31-1024\x12\x36\n\x03xmx\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x36\x34-16384\x12\x36\n\x03xms\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x36\x34-16384\"\xd9\x01\n\x0cPXFConfigSet\x12H\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.PXFConfigB\x04\xe8\xc7\x31\x01\x12=\n\x0buser_config\x18\x02 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.PXFConfig\x12@\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.PXFConfigBp\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplumb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.greenplum.v1.pxf_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplum'
  _PXFCONFIG.fields_by_name['connection_timeout']._options = None
  _PXFCONFIG.fields_by_name['connection_timeout']._serialized_options = b'\372\3071\0055-600'
  _PXFCONFIG.fields_by_name['upload_timeout']._options = None
  _PXFCONFIG.fields_by_name['upload_timeout']._serialized_options = b'\372\3071\0055-600'
  _PXFCONFIG.fields_by_name['max_threads']._options = None
  _PXFCONFIG.fields_by_name['max_threads']._serialized_options = b'\372\3071\0061-1024'
  _PXFCONFIG.fields_by_name['pool_core_size']._options = None
  _PXFCONFIG.fields_by_name['pool_core_size']._serialized_options = b'\372\3071\0061-1024'
  _PXFCONFIG.fields_by_name['pool_queue_capacity']._options = None
  _PXFCONFIG.fields_by_name['pool_queue_capacity']._serialized_options = b'\372\3071\003>=0'
  _PXFCONFIG.fields_by_name['pool_max_size']._options = None
  _PXFCONFIG.fields_by_name['pool_max_size']._serialized_options = b'\372\3071\0061-1024'
  _PXFCONFIG.fields_by_name['xmx']._options = None
  _PXFCONFIG.fields_by_name['xmx']._serialized_options = b'\372\3071\01064-16384'
  _PXFCONFIG.fields_by_name['xms']._options = None
  _PXFCONFIG.fields_by_name['xms']._serialized_options = b'\372\3071\01064-16384'
  _PXFCONFIGSET.fields_by_name['effective_config']._options = None
  _PXFCONFIGSET.fields_by_name['effective_config']._serialized_options = b'\350\3071\001'
  _globals['_PXFCONFIG']._serialized_start=138
  _globals['_PXFCONFIG']._serialized_end=719
  _globals['_PXFCONFIGSET']._serialized_start=722
  _globals['_PXFCONFIGSET']._serialized_end=939
# @@protoc_insertion_point(module_scope)
